@@ -36,6 +36,8 @@ struct _GnomeDruidPrivate
 	GnomeDruidPage *current;
 	GList *children;
 
+	GtkWidget *bbox;
+
 	gboolean show_finish : 1; /* if TRUE, then we are showing the finish button instead of the next button */
 	gboolean show_help : 1;
 };
@@ -52,8 +54,6 @@ enum {
 };
 
 
-static void    gnome_druid_instance_init   (GnomeDruid      *druid);
-static void    gnome_druid_class_init      (GnomeDruidClass *klass);
 static void    gnome_druid_destroy         (GtkObject       *object);
 static void    gnome_druid_finalize        (GObject         *object);
 static void    gnome_druid_set_property    (GObject         *object,
@@ -95,7 +95,7 @@ static guint druid_signals[LAST_SIGNAL] = { 0 };
 
 /* define the _get_type method and parent_class */
 GNOME_CLASS_BOILERPLATE(GnomeDruid, gnome_druid,
-			GtkContainer, gtk_container, GTK_TYPE_CONTAINER)
+			GtkContainer, GTK_TYPE_CONTAINER)
 
 static void
 gnome_druid_class_init (GnomeDruidClass *klass)
@@ -110,21 +110,23 @@ gnome_druid_class_init (GnomeDruidClass *klass)
 	widget_class = (GtkWidgetClass*) klass;
 	container_class = (GtkContainerClass*) klass;
 
-	druid_signals[CANCEL] = 
-		gtk_signal_new ("cancel",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomeDruidClass, cancel),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
-	
-	druid_signals[HELP] = 
-		gtk_signal_new ("help",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomeDruidClass, help),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
+	druid_signals[CANCEL] =
+		g_signal_new ("cancel",
+			      G_TYPE_FROM_CLASS (gobject_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GnomeDruidClass, cancel),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
+
+	druid_signals[HELP] =
+		g_signal_new ("help",
+			      G_TYPE_FROM_CLASS (gobject_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GnomeDruidClass, help),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
 
 	object_class->destroy = gnome_druid_destroy;
 	gobject_class->set_property = gnome_druid_set_property;
@@ -180,16 +182,35 @@ gnome_druid_instance_init (GnomeDruid *druid)
 	GTK_WIDGET_SET_FLAGS (druid->finish, GTK_CAN_DEFAULT);
 	druid->help = gtk_button_new_from_stock (GTK_STOCK_HELP);
 	GTK_WIDGET_SET_FLAGS (druid->help, GTK_CAN_DEFAULT);
-	gtk_widget_set_parent (druid->back, GTK_WIDGET (druid));
-	gtk_widget_set_parent (druid->next, GTK_WIDGET (druid));
-	gtk_widget_set_parent (druid->cancel, GTK_WIDGET (druid));
-	gtk_widget_set_parent (druid->finish, GTK_WIDGET (druid));
-	gtk_widget_set_parent (druid->help, GTK_WIDGET (druid));
 	gtk_widget_show (druid->back);
 	gtk_widget_show (druid->next);
 	gtk_widget_show (druid->cancel);
-	gtk_widget_show (druid->finish);
-	gtk_widget_show (druid->help);
+
+	druid->_priv->bbox = gtk_hbutton_box_new ();
+	gtk_button_box_set_layout (GTK_BUTTON_BOX (druid->_priv->bbox),
+				   GTK_BUTTONBOX_END);
+	/* FIXME: use a style property for these */
+	gtk_box_set_spacing (GTK_BOX (druid->_priv->bbox), 10);
+	gtk_container_set_border_width (GTK_CONTAINER (druid->_priv->bbox), 5);
+	gtk_widget_set_parent (druid->_priv->bbox, GTK_WIDGET (druid));
+	gtk_widget_show (druid->_priv->bbox);
+
+	gtk_box_pack_end (GTK_BOX (druid->_priv->bbox), druid->help,
+			  FALSE, TRUE, 0);
+	gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (druid->_priv->bbox),
+					    druid->help, TRUE);
+
+	gtk_box_pack_end (GTK_BOX (druid->_priv->bbox), druid->cancel,
+			  FALSE, TRUE, 0);
+
+	gtk_box_pack_end (GTK_BOX (druid->_priv->bbox), druid->back,
+			  FALSE, TRUE, 0);
+
+	gtk_box_pack_end (GTK_BOX (druid->_priv->bbox), druid->next,
+			  FALSE, TRUE, 0);
+
+	gtk_box_pack_end (GTK_BOX (druid->_priv->bbox), druid->finish,
+			  FALSE, TRUE, 0);
 
 	/* other flags */
 	druid->_priv->current = NULL;
@@ -197,26 +218,16 @@ gnome_druid_instance_init (GnomeDruid *druid)
 	druid->_priv->show_finish = FALSE;
 	druid->_priv->show_help = FALSE;
 
-	gtk_signal_connect (GTK_OBJECT (druid->back),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (gnome_druid_back_callback),
-			    druid);
-	gtk_signal_connect (GTK_OBJECT (druid->next),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (gnome_druid_next_callback),
-			    druid);
-	gtk_signal_connect (GTK_OBJECT (druid->cancel),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (gnome_druid_cancel_callback),
-			    druid);
-	gtk_signal_connect (GTK_OBJECT (druid->finish),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (gnome_druid_next_callback),
-			    druid);
-	gtk_signal_connect (GTK_OBJECT (druid->help),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (gnome_druid_help_callback),
-			    druid);
+	g_signal_connect (druid->back, "clicked",
+			  G_CALLBACK (gnome_druid_back_callback), druid);
+	g_signal_connect (druid->next, "clicked",
+			  G_CALLBACK (gnome_druid_next_callback), druid);
+	g_signal_connect (druid->cancel, "clicked",
+			  G_CALLBACK (gnome_druid_cancel_callback), druid);
+	g_signal_connect (druid->finish, "clicked",
+			  G_CALLBACK (gnome_druid_next_callback), druid);
+	g_signal_connect (druid->help, "clicked",
+			  G_CALLBACK (gnome_druid_help_callback), druid);
 }
 
 
@@ -233,24 +244,13 @@ gnome_druid_destroy (GtkObject *object)
 
 	druid = GNOME_DRUID (object);
 
-	if(druid->back) {
-		gtk_widget_destroy (druid->back);
+	if(druid->_priv->bbox) {
+		gtk_widget_destroy (druid->_priv->bbox);
+		druid->_priv->bbox = NULL;
 		druid->back = NULL;
-	}
-	if(druid->next) {
-		gtk_widget_destroy (druid->next);
 		druid->next = NULL;
-	}
-	if(druid->cancel) {
-		gtk_widget_destroy (druid->cancel);
 		druid->cancel = NULL;
-	}
-	if(druid->finish) {
-		gtk_widget_destroy (druid->finish);
 		druid->finish = NULL;
-	}
-	if(druid->help) {
-		gtk_widget_destroy (druid->help);
 		druid->help = NULL;
 	}
 
@@ -262,7 +262,7 @@ gnome_druid_destroy (GtkObject *object)
 		gtk_container_remove (GTK_CONTAINER (druid), GTK_WIDGET(child));
 	}
 
-	GNOME_CALL_PARENT_HANDLER (GTK_OBJECT_CLASS, destroy, (object));
+	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
@@ -278,7 +278,7 @@ gnome_druid_finalize (GObject *object)
 	g_free(druid->_priv);
 	druid->_priv = NULL;
 
-	GNOME_CALL_PARENT_HANDLER (G_OBJECT_CLASS, finalize, (object));
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 static void
@@ -330,7 +330,7 @@ gnome_druid_size_request (GtkWidget *widget,
 	GtkRequisition child_requisition;
 	GnomeDruidPage *child;
 	int border;
-	
+
 	g_return_if_fail (widget != NULL);
 	g_return_if_fail (GNOME_IS_DRUID (widget));
 
@@ -350,15 +350,16 @@ gnome_druid_size_request (GtkWidget *widget,
 				gtk_widget_unmap (GTK_WIDGET(child));
 		}
 	}
-	
+
         requisition->width = temp_width + 2 * border;
         requisition->height = temp_height + 2 * border;
 
+#if 0
 	/* In an Attempt to show how the widgets are packed,
 	 * here's a little diagram.
-	 * 
+	 *
 	 * [  Help  ] ------------- [  Back  ] [  Next  ]    [ Cancel ]
-	 *             / 
+	 *             /
 	 *     This part needs to be at least 1 button width.
 	 *     In addition, there is 1/4 X Button width between Cancel and Next,
 	 *     and a GNOME_PAD_SMALL between Next and Back.
@@ -391,10 +392,13 @@ gnome_druid_size_request (GtkWidget *widget,
 	temp_height += GNOME_PAD_SMALL;
 
 	temp_width = temp_width * 21/4  + GNOME_PAD_SMALL * 3;
+#endif
+
+	gtk_widget_size_request (druid->_priv->bbox, &child_requisition);
 
 	/* pick which is bigger, the buttons, or the GnomeDruidPages */
-	requisition->width = MAX (temp_width, requisition->width);
-	requisition->height += temp_height + GNOME_PAD_SMALL * 2;
+	requisition->width = MAX (child_requisition.width, requisition->width);
+	requisition->height += child_requisition.height + GNOME_PAD_SMALL * 2;
 }
 
 static void
@@ -406,7 +410,7 @@ gnome_druid_size_allocate (GtkWidget *widget,
 	gint button_height;
 	GList *list;
 	int border;
-	
+
 	g_return_if_fail (widget != NULL);
 	g_return_if_fail (GNOME_IS_DRUID (widget));
 
@@ -415,6 +419,7 @@ gnome_druid_size_allocate (GtkWidget *widget,
 
 	border = GTK_CONTAINER(widget)->border_width;
 
+#if 0
 	/* deal with the buttons */
 	child_allocation.width = child_allocation.height = 0;
 	child_allocation.width = druid->back->requisition.width;
@@ -445,7 +450,14 @@ gnome_druid_size_allocate (GtkWidget *widget,
 	gtk_widget_size_allocate (druid->back, &child_allocation);
 	child_allocation.x = allocation->x + border;
 	gtk_widget_size_allocate (druid->help, &child_allocation);
-	
+#endif
+	button_height = druid->_priv->bbox->requisition.height;
+	child_allocation.x = allocation->x;
+	child_allocation.y = allocation->y + allocation->height - button_height;
+	child_allocation.height = button_height;
+	child_allocation.width = allocation->width;
+	gtk_widget_size_allocate (druid->_priv->bbox, &child_allocation);
+
 	/* Put up the GnomeDruidPage */
 	child_allocation.x = allocation->x + border;
 	child_allocation.y = allocation->y + border;
@@ -480,6 +492,7 @@ gnome_druid_map (GtkWidget *widget)
 	druid = GNOME_DRUID (widget);
 	GTK_WIDGET_SET_FLAGS (druid, GTK_MAPPED);
 
+#if 0
 	gtk_widget_map (druid->back);
 	if (druid->_priv->show_finish)
 		gtk_widget_map (druid->finish);
@@ -488,6 +501,8 @@ gnome_druid_map (GtkWidget *widget)
 	if (druid->_priv->show_help)
 		gtk_widget_map (druid->help);
 	gtk_widget_map (druid->cancel);
+#endif
+	gtk_widget_map (druid->_priv->bbox);
 	if (druid->_priv->current &&
 	    GTK_WIDGET_VISIBLE (druid->_priv->current) &&
 	    !GTK_WIDGET_MAPPED (druid->_priv->current)) {
@@ -505,15 +520,17 @@ gnome_druid_unmap (GtkWidget *widget)
 
 	druid = GNOME_DRUID (widget);
 	GTK_WIDGET_UNSET_FLAGS (druid, GTK_MAPPED);
-
+#if 0
 	gtk_widget_unmap (druid->back);
 	if (druid->_priv->show_finish)
 		gtk_widget_unmap (druid->finish);
 	else
 		gtk_widget_unmap (druid->next);
-	gtk_widget_unmap (druid->cancel);	
+	gtk_widget_unmap (druid->cancel);
 	if (druid->_priv->show_help)
 		gtk_widget_unmap (druid->help);
+#endif
+	gtk_widget_unmap (druid->_priv->bbox);
 	if (druid->_priv->current &&
 	    GTK_WIDGET_VISIBLE (druid->_priv->current) &&
 	    GTK_WIDGET_MAPPED (druid->_priv->current))
@@ -536,7 +553,7 @@ gnome_druid_remove (GtkContainer *widget,
 {
 	GnomeDruid *druid;
 	GList *list;
-	
+
 	g_return_if_fail (widget != NULL);
 	g_return_if_fail (GNOME_IS_DRUID (widget));
 	g_return_if_fail (child != NULL);
@@ -544,7 +561,7 @@ gnome_druid_remove (GtkContainer *widget,
 	druid = GNOME_DRUID (widget);
 
 	list = g_list_find (druid->_priv->children, child);
-	/* Is it a page? */ 
+	/* Is it a page? */
 	if (list != NULL) {
 		/* If we are mapped and visible, we want to deal with changing the page. */
 		if ((GTK_WIDGET_MAPPED (GTK_WIDGET (widget))) &&
@@ -581,11 +598,15 @@ gnome_druid_forall (GtkContainer *container,
 		(* callback) (GTK_WIDGET (child), callback_data);
 	}
 	if (include_internals) {
+		/* FIXME: should this be gtk_contianer_forall() ? */
+		(* callback) (druid->_priv->bbox, callback_data);
+#if 0
 		(* callback) (druid->back, callback_data);
 		(* callback) (druid->next, callback_data);
 		(* callback) (druid->cancel, callback_data);
 		(* callback) (druid->finish, callback_data);
 		(* callback) (druid->help, callback_data);
+#endif
 	}
 }
 
@@ -612,6 +633,9 @@ gnome_druid_expose (GtkWidget      *widget,
 			gtk_container_propagate_expose (GTK_CONTAINER (widget),
 							child, event);
 		}
+		gtk_container_propagate_expose (GTK_CONTAINER (widget),
+						druid->_priv->bbox, event);
+#if 0
 		gtk_container_propagate_expose (GTK_CONTAINER (widget),
 						druid->back, event);
 		gtk_container_propagate_expose (GTK_CONTAINER (widget),
@@ -622,6 +646,7 @@ gnome_druid_expose (GtkWidget      *widget,
 						druid->finish, event);
 		gtk_container_propagate_expose (GTK_CONTAINER (widget),
 						druid->help, event);
+#endif
 	}
 	return FALSE;
 }
@@ -676,7 +701,7 @@ gnome_druid_cancel_callback (GtkWidget *button, GtkWidget *druid)
 	     if (gnome_druid_page_cancel (GNOME_DRUID (druid)->_priv->current))
 		     return;
 
-	     gtk_signal_emit (GTK_OBJECT (druid), druid_signals [CANCEL]);
+	     g_signal_emit (druid, druid_signals [CANCEL], 0);
      }
 }
 
@@ -684,7 +709,7 @@ static void
 gnome_druid_help_callback (GtkWidget  *button,
 			   GnomeDruid *druid)
 {
-	gtk_signal_emit (GTK_OBJECT (druid), druid_signals [HELP]);
+	g_signal_emit (druid, druid_signals [HELP], 0);
 }
 
 /* Public Functions */
@@ -699,24 +724,25 @@ gnome_druid_help_callback (GtkWidget  *button,
 GtkWidget *
 gnome_druid_new (void)
 {
-	return GTK_WIDGET (gtk_type_new (GNOME_TYPE_DRUID));
+	return g_object_new (GNOME_TYPE_DRUID, NULL);
 }
 
 /**
  * gnome_druid_new_with_window:
- * @title: A title of the window
- * @parent: The parent of this window (transient_for)
- * @close_on_cancel: Close the window when cancel is pressed
- * @window: Optional return of the #GtkWindow created
+ * @title: A title of the window.
+ * @parent: The parent of this window (transient_for).
+ * @close_on_cancel: %TRUE if the window should be closed when cancel is
+ * pressed.
+ * @window: Optional return of the #GtkWindow created.
  *
- * Description: Creates a new #GnomeDruid widget.  It also creates a new
+ * Description: Creates a new #GnomeDruid widget. It also creates a new
  * toplevel window with the title of @title (which can be %NULL) and a parent
- * of @parent (which also can be %NULL).  The window and the druid will both be
+ * of @parent (which also can be %NULL). The window and the druid will both be
  * shown.  If you need the window widget pointer you can optionally get it
  * through the last argument.  When the druid gets destroyed, so will the
  * window that is created here.
  *
- * Returns:  A new #GnomeDruid widget
+ * Returns:  A new #GnomeDruid widget.
  **/
 GtkWidget *
 gnome_druid_new_with_window (const char *title,
@@ -724,9 +750,9 @@ gnome_druid_new_with_window (const char *title,
 			     gboolean close_on_cancel,
 			     GtkWidget **window)
 {
-	GtkWidget *druid = gtk_type_new (GNOME_TYPE_DRUID);
+	GtkWidget *druid = g_object_new (GNOME_TYPE_DRUID, NULL);
 
-	/* make sure we always set window to NULL, even in 
+	/* make sure we always set window to NULL, even in
 	 * case of precondition errors */
 	if (window != NULL)
 		*window = NULL;
@@ -746,19 +772,21 @@ gnome_druid_new_with_window (const char *title,
 
 /**
  * gnome_druid_construct_with_window:
- * @druid: The #GnomeDruid
- * @title: A title of the window
- * @parent: The parent of this window (transient_for)
- * @close_on_cancel: Close the window when cancel is pressed
- * @window: Optional return of the #GtkWindow created
+ * @druid: The #GnomeDruid.
+ * @title: A title of the window.
+ * @parent: The parent of this window (transient_for).
+ * @close_on_cancel: %TRUE if the window should be closed when cancel is
+ * pressed.
+ * @window: Optional return of the #GtkWindow created.
  *
  * Description: Creates a new toplevel window with the title of @title (which
  * can be %NULL) and a parent of @parent (which also can be %NULL).  The @druid
- * will be placed inside this window.  The window and the druid will both be
- * shown.  If you need the window widget pointer you can optionally get it
- * through the last argument.  When the druid gets destroyed, so will the
+ * will be placed inside this window. The window and the druid will both be
+ * shown. If you need the window widget pointer you can optionally get it
+ * through the last argument. When the druid gets destroyed, so will the
  * window that is created here.
- * See #gnome_druid_new_with_window.
+ *
+ * See also gnome_druid_new_with_window().
  **/
 void
 gnome_druid_construct_with_window (GnomeDruid *druid,
@@ -769,7 +797,7 @@ gnome_druid_construct_with_window (GnomeDruid *druid,
 {
 	GtkWidget *win;
 
-	/* make sure we always set window to NULL, even in 
+	/* make sure we always set window to NULL, even in
 	 * case of precondition errors */
 	if (window != NULL)
 		*window = NULL;
@@ -794,19 +822,17 @@ gnome_druid_construct_with_window (GnomeDruid *druid,
 	gtk_widget_show (win);
 
 	if (close_on_cancel) {
-		/* Use while_alive just for sanity */
-		gtk_signal_connect_object_while_alive
-			(GTK_OBJECT (druid), "cancel",
-			 GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			 GTK_OBJECT (win));
+		g_signal_connect_object (druid, "cancel",
+					 G_CALLBACK (gtk_widget_destroy),
+					 win,
+					 G_CONNECT_SWAPPED);
 	}
 
 	/* When the druid gets destroyed so does the window */
-	/* Use while_alive just for sanity */
-	gtk_signal_connect_object_while_alive
-		(GTK_OBJECT (druid), "destroy",
-		 GTK_SIGNAL_FUNC (gtk_widget_destroy),
-		 GTK_OBJECT (win));
+	g_signal_connect_object (druid, "destroy",
+				 G_CALLBACK (gtk_widget_destroy),
+				 win,
+				 G_CONNECT_SWAPPED);
 
 	/* return the window */
 	if (window != NULL)
@@ -817,13 +843,13 @@ gnome_druid_construct_with_window (GnomeDruid *druid,
 /**
  * gnome_druid_set_buttons_sensitive
  * @druid: A Druid.
- * @back_sensitive: The sensitivity of the back button.
- * @next_sensitive: The sensitivity of the next button.
- * @cancel_sensitive: The sensitivity of the cancel button.
- * @help_sensitive: The sensitivity of the help button.
+ * @back_sensitive: %TRUE if the back button is sensitive.
+ * @next_sensitive: %TRUE if the next button is sensitive.
+ * @cancel_sensitive: %TRUE if the cancel button is sensitive.
+ * @help_sensitive: %TRUE if the help button is sensitive.
  *
- * Description: Sets the sensitivity of the @druid's control-buttons.  If the
- * variables are TRUE, then they will be clickable.  This function is used
+ * Description: Sets the sensitivity of @druid's control-buttons.  If the
+ * variables are %TRUE, then they will be clickable. This function is used
  * primarily by the actual GnomeDruidPage widgets.
  **/
 
@@ -843,26 +869,13 @@ gnome_druid_set_buttons_sensitive (GnomeDruid *druid,
 	gtk_widget_set_sensitive (druid->help, help_sensitive);
 }
 
-static void
-undefault_button (GtkWidget *widget)
-{
-	GtkWidget *toplevel;
-
-	toplevel = gtk_widget_get_toplevel (widget);
-
-	if (GTK_IS_WINDOW (toplevel) &&
-	    GTK_WINDOW (toplevel)->default_widget == widget) {
-		gtk_window_set_default (GTK_WINDOW (toplevel), NULL);
-	}
-}
-
 /**
  * gnome_druid_set_show_finish
- * @druid: A Druid widget.
- # @show_finish: If %TRUE, then the "Cancel" button is changed to be "Finish"
+ * @druid: A #GnomeDruid widget.
+ * @show_finish: If %TRUE, then the "Next" button is changed to be "Finish"
  *
- * Sets the "Help" button on the druid to be visible in the lower left corner of
- * the widget, if @show_finish is %TRUE.
+ * Used to specify if @druid is currently showing the last page of the sequence
+ * (and hence should display "Finish", rather than "Next").
  **/
 void
 gnome_druid_set_show_finish (GnomeDruid *druid,
@@ -874,29 +887,22 @@ gnome_druid_set_show_finish (GnomeDruid *druid,
 		return;
 
 	if (show_finish) {
-		undefault_button (druid->next);
-
-		if (GTK_WIDGET_MAPPED (druid->next)) {
-			gtk_widget_unmap (druid->next);
-			gtk_widget_map (druid->finish);
-		}
+		gtk_widget_hide (druid->next);
+		gtk_widget_show (druid->finish);
 	} else {
-		undefault_button (druid->finish);
-
-		if (GTK_WIDGET_MAPPED (druid->finish)) {
-			gtk_widget_unmap (druid->finish);
-			gtk_widget_map (druid->next);
-		}
+		gtk_widget_hide (druid->finish);
+		gtk_widget_show (druid->next);
 	}
 	druid->_priv->show_finish = show_finish?TRUE:FALSE;
 }
 
 /**
- * gnome_druid_set_show_finish
+ * gnome_druid_set_show_help
  * @druid: A #GnomeDruid.
- # @show_finish: TRUE, if the "Help" button is to be shown.
+ * @show_help: %TRUE, if the "Help" button is to be shown, %FALSE otherwise.
  *
- * Sets the 
+ * Sets the "Help" button on the druid to be visible in the lower left corner of
+ * the widget, if @show_help is %TRUE.
  **/
 void
 gnome_druid_set_show_help (GnomeDruid *druid,
@@ -908,14 +914,11 @@ gnome_druid_set_show_help (GnomeDruid *druid,
 		return;
 
 	if (show_help) {
-		if (GTK_WIDGET_MAPPED (druid))
-			gtk_widget_map (druid->help);
+		gtk_widget_show (druid->help);
 	} else {
-		undefault_button (druid->help);
-		if (GTK_WIDGET_MAPPED (druid->help))
-			gtk_widget_unmap (druid->help);
+		gtk_widget_hide (druid->help);
 	}
-	druid->_priv->show_finish = show_help?TRUE:FALSE;
+	druid->_priv->show_help = show_help?TRUE:FALSE;
 }
 
 
@@ -923,10 +926,10 @@ gnome_druid_set_show_help (GnomeDruid *druid,
  * gnome_druid_prepend_page:
  * @druid: A Druid widget.
  * @page: The page to be inserted.
- * 
+ *
  * Description: This will prepend a GnomeDruidPage into the internal list of
- * pages that the @druid has.  Since #GnomeDruid is just a container, you will
- * need to also call #gtk_widget_show on the page, otherwise the page will not
+ * pages that the @druid has. Since #GnomeDruid is just a container, you will
+ * need to also call gtk_widget_show() on the page, otherwise the page will not
  * be shown.
  **/
 void
@@ -942,14 +945,14 @@ gnome_druid_prepend_page (GnomeDruid *druid,
 }
 /**
  * gnome_druid_insert_page:
- * @druid: A Druid widget.
+ * @druid: A #GnomeDruid widget.
  * @back_page: The page prior to the page to be inserted.
  * @page: The page to insert.
- * 
+ *
  * Description: This will insert @page after @back_page into the list of
- * internal pages that the @druid has.  If @back_page is not present in the list
- * or %NULL, @page will be prepended to the list.  Since #GnomeDruid is just a
- * container, you will need to also call #gtk_widget_show on the page,
+ * internal pages that the @druid has.  If @back_page is not present in the
+ * list or %NULL, @page will be prepended to the list.  Since #GnomeDruid is
+ * just a container, you will need to also call gtk_widget_show() on the page,
  * otherwise the page will not be shown.
  **/
 void
@@ -971,7 +974,7 @@ gnome_druid_insert_page (GnomeDruid *druid,
 		GList *new_el = g_list_alloc ();
 		new_el->next = list->next;
 		new_el->prev = list;
-		if (new_el->next) 
+		if (new_el->next)
 			new_el->next->prev = new_el;
 		new_el->prev->next = new_el;
 		new_el->data = (gpointer) page;
@@ -993,13 +996,13 @@ gnome_druid_insert_page (GnomeDruid *druid,
 }
 
 /**
- * gnome_druid_append_page: 
- * @druid: A Druid widget.
+ * gnome_druid_append_page:
+ * @druid: A #GnomeDruid widget.
  * @page: The #GnomeDruidPage to be appended.
- * 
- * Description: This will append @page onto the end of the internal list.  
+ *
+ * Description: This will append @page onto the end of the internal list.
  * Since #GnomeDruid is just a container, you will need to also call
- * #gtk_widget_show on the page, otherwise the page will not be shown.
+ * gtk_widget_show() on the page, otherwise the page will not be shown.
  **/
 void
 gnome_druid_append_page (GnomeDruid *druid,
@@ -1016,13 +1019,13 @@ gnome_druid_append_page (GnomeDruid *druid,
 		gnome_druid_insert_page (druid, GNOME_DRUID_PAGE (list->data), page);
 	} else {
 		gnome_druid_insert_page (druid, NULL, page);
-	}	
+	}
 }
 /**
  * gnome_druid_set_page:
- * @druid: A Druid widget.
+ * @druid: A #GnomeDruid widget.
  * @page: The #GnomeDruidPage to be brought to the foreground.
- * 
+ *
  * Description: This will make @page the currently showing page in the druid.
  * @page must already be in the druid.
  **/
